CodeMirror: Code Folding Demo

## Code Folding Demo

JavaScript:
HTML:
JSON with custom widget:
{ "menu": { "id": "file", "value": "File", "popup": { "menuitem": [ {"value": "New", "onclick": "CreateNewDoc()"}, {"value": "Open", "onclick": "OpenDoc()"}, {"value": "Close", "onclick": "CloseDoc()"} ] } } }
Python:
def foo(): do_some_stuff() here return None class Bar: __init__(self): if True: print("True") else: print("False") this_code_makes_no_sense(): pass # A comment
Markdown: